==========================
Firebird driver for Python
==========================

This package provides official Python Database API 2.0-compliant driver for the open
source relational database Firebird®. In addition to the minimal feature set of
the standard Python DB API, this driver also exposes the new (interface-based)
client API introduced in Firebird 3, and number of additional extensions and
enhancements for convenient use of Firebird RDBMS.

Requires: Firebird 3+, Python 3.8+

See firebird-lib package for optional extensions to this driver.
